@@ -39,7 +39,7 @@
 
 const char *title =
   "AVRA: advanced AVR macro assembler Version %i.%i.%i Build %i (%s)\n"
-  "Copyright (C) 1998-2006. Check out README file for more info\n"
+  "Copyright (C) 1998-2007. Check out README file for more info\n"
   "\n"
   "   AVRA is an open source assembler for Atmel AVR microcontroller family\n"
   "   It can be used as a replacement of 'AVRASM32.EXE' the original assembler\n"
@@ -106,14 +106,15 @@ int main(int argc, char *argv[])
     define_arg(args, ARG_DEVICES,     ARGTYPE_BOOLEAN,              0,  "devices",     NULL);
     define_arg(args, ARG_VER,         ARGTYPE_BOOLEAN,              0,  "version",     NULL);
     define_arg(args, ARG_HELP,        ARGTYPE_BOOLEAN,             'h', "help",        NULL);
-    define_arg(args, ARG_WRAP,        ARGTYPE_BOOLEAN,             'w', "wrap",        NULL);
+    define_arg(args, ARG_WRAP,        ARGTYPE_BOOLEAN,             'w', "wrap",        NULL);	// Not implemented ? B.A.
     define_arg(args, ARG_WARNINGS,    ARGTYPE_STRING_MULTISINGLE,  'W', "warn",        NULL);
-    define_arg(args, ARG_FILEFORMAT,  ARGTYPE_CHAR_ATTACHED,       'f', "filetype",    "0");
+    define_arg(args, ARG_FILEFORMAT,  ARGTYPE_CHAR_ATTACHED,       'f', "filetype",    "0");	// Not implemented ? B.A.
     define_arg(args, ARG_LISTFILE,    ARGTYPE_STRING,              'l', "listfile",    NULL);
-    define_arg(args, ARG_OUTFILE,     ARGTYPE_STRING,              'o', "outfile",     NULL);
+    define_arg(args, ARG_OUTFILE,     ARGTYPE_STRING,              'o', "outfile",     NULL);	// Not implemented ? B.A.
     define_arg(args, ARG_MAPFILE,     ARGTYPE_STRING,              'm', "mapfile",     NULL);
-    define_arg(args, ARG_DEBUGFILE,   ARGTYPE_STRING,              'd', "debugfile",   NULL);
-    define_arg(args, ARG_EEPFILE,     ARGTYPE_STRING,              'e', "eepfile",     NULL);
+    define_arg(args, ARG_DEBUGFILE,   ARGTYPE_STRING,              'd', "debugfile",   NULL);	// Not implemented ? B.A.
+    define_arg(args, ARG_EEPFILE,     ARGTYPE_STRING,              'e', "eepfile",     NULL);	// Not implemented ? B.A.
+
 
     c = read_args(args, argc, argv);
     
@@ -263,7 +264,7 @@ int load_arg_defines(struct prog_info *pi)
 
   for(define = GET_ARG(pi->args, ARG_DEFINE); define; define = define->next) {
 	  strcpy(buff, define->data);
-	  expr = get_next_token(buff, TERM_EQUAL);
+	  expr = get_next_token( buff, TERM_EQUAL);
 	  if(expr) {
   	  // we reach this, when there is actually a value passed..	
 	    if(!get_expr(pi, expr, &i)) {
@@ -273,11 +274,11 @@ int load_arg_defines(struct prog_info *pi)
   	  // if user didnt specify a value, we default to 1 
   	  i = 1; 
     }
-		/* B.A. : New. Forward references allowed. But check, if everything is ok ... */
-  	if(pi->pass==PASS_1) { /* Pass 1 */
+	/* B.A. : New. Forward references allowed. But check, if everything is ok ... */
+    if(pi->pass==PASS_1) { /* Pass 1 */
       if(test_constant(pi,buff,NULL)!=NULL) {
-        fprintf(stderr,"Error: Can't define symbol %s twice\n", buff);
-        return(False);
+        	fprintf(stderr,"Error: Can't define symbol %s twice\n", buff);
+        	return(False);
       }
       if(def_const(pi, buff, i)==False)
         return(False);
@@ -301,39 +302,35 @@ int load_arg_defines(struct prog_info *pi)
  * prog_info
  ******************************************/
 struct prog_info *get_pi(struct args *args) {
-    struct prog_info *pi;
-    struct data_list *warnings;
+	struct prog_info *pi;
+	struct data_list *warnings;
 
-  pi = (struct prog_info *)calloc(1, sizeof(struct prog_info));
-  memset(pi, 0, sizeof(struct prog_info));
-  if(pi) {
-	  pi->args = args;
-	  pi->device = get_device(pi,NULL);
-	  if (GET_ARG(args, ARG_LISTFILE) == NULL) {
-      pi->list_on = False;
-    }
-    else {
-      pi->list_on = True;
-    }
-	  if (GET_ARG(args, ARG_MAPFILE) == NULL) {
-      pi->map_on = False;
-    }
-    else {
-      pi->map_on = True;
-    }
-  
-    for(warnings = GET_ARG(args, ARG_WARNINGS); warnings; warnings = warnings->next) {
-      if(!nocase_strcmp(warnings->data, "NoRegDef"))
-        pi->NoRegDef = 1;
-    }
-
-	  pi->segment = SEGMENT_CODE;
-	  pi->dseg_addr = pi->device->ram_start;
-	  pi->max_errors = atoi(GET_ARG(args, ARG_MAX_ERRORS));
-	  pi->pass=PASS_1; 		/* B.A. : The pass variable is now stored in the pi struct */
-	  return(pi);
-  }
-  else return(NULL);
+	pi = (struct prog_info *)calloc(1, sizeof(struct prog_info));
+	if(!pi) 
+		return(NULL);
+	memset(pi, 0, sizeof(struct prog_info));
+	pi->args = args;
+	pi->device = get_device(pi,NULL);
+	if(GET_ARG(args, ARG_LISTFILE) == NULL) {
+		pi->list_on = False;
+	} else {
+		pi->list_on = True;
+	}
+	if(GET_ARG(args, ARG_MAPFILE) == NULL) {
+		pi->map_on = False;
+	} else {
+		pi->map_on = True;
+	}
+	for(warnings = GET_ARG(args, ARG_WARNINGS); warnings; warnings = warnings->next) {
+		if(!nocase_strcmp(warnings->data, "NoRegDef"))
+			pi->NoRegDef = 1;
+	}
+	pi->segment = SEGMENT_CODE;
+	pi->dseg_addr = pi->device->ram_start;
+	pi->max_errors = atoi(GET_ARG(args, ARG_MAX_ERRORS));
+	pi->pass=PASS_1; 		/* B.A. : The pass variable is now stored in the pi struct */
+	pi->time=time(NULL); 		/* B.A. : Now use a global timestamp  */
+	return(pi);
 }
 
 void free_pi(struct prog_info *pi) {
@@ -367,8 +364,8 @@ void print_msg(struct prog_info *pi, int type, char *fmt, ... )
 		fprintf(stderr, "Error: Unable to allocate memory!\n");
 	} else {
 		if(type != MSGTYPE_APPEND) { 				/* B.A. Added for .message directive */
-			if(pi->fi->include_file->name != NULL) { 	/* B.A.: Skip, if filename is NULL */
-				/* check if adding path name is needed*/	  
+			if((pi->fi != NULL) && (pi->fi->include_file->name != NULL)) { 	/* B.A.: Skip, if filename or fi is NULL (Bug 1462900) */
+				/* check if adding path name is needed*/
 				pc = strstr(pi->fi->include_file->name, pi->root_path);
 				if(pc == NULL) { 
 					fprintf(stderr, "%s%s(%d) : ", pi->root_path ,pi->fi->include_file->name, pi->fi->line_number);
@@ -562,7 +559,7 @@ void print_orglist(struct prog_info *pi)
 					printf("   EEPROM"); break;
 				printf("INVALID SEGMENT DATA !\n");
 			}	
-			printf("   :  Start = 0x%04X, End = 0x%04X, Length = 0x%04X\n",
+			printf("    :  Start = 0x%04X, End = 0x%04X, Length = 0x%04X\n",
 				orglist->start,orglist->start+orglist->length-1,orglist->length);
 		}
 		orglist=orglist->next;
@@ -598,8 +595,8 @@ int test_orglist(struct prog_info *pi)
 						// fprintf(stderr,"This device has no RAM. Don't use .DSEG \n");
 						// error_count++;
 						break;
-					}
-					if(((orglist->start + orglist->length) > pi->device->ram_size) ||
+					} 	// Fix bug 1742436. Added missing pi->device->ram_start
+					if(((orglist->start + orglist->length) > (pi->device->ram_size + pi->device->ram_start)) ||
 					    (orglist->start < pi->device->ram_start)) {
 						fprintf(stderr,"Data segment exceeds valid address range [0x%04X..0x%04X] :",
 							pi->device->ram_start,pi->device->ram_start+pi->device->ram_size-1);
@@ -608,8 +605,8 @@ int test_orglist(struct prog_info *pi)
 						error_count++;
 					}
 					break;
-				case SEGMENT_EEPROM:
-					if(pi->device->ram_size == 0) {
+				case SEGMENT_EEPROM: // Fix bug 1742437 : replace ram_size by eeprom_size
+					if(pi->device->eeprom_size == 0) {
 						// Error message is generated in .ESEG directive. Skip ...
 						// fprintf(stderr,"This device has no EEPROM. Don't use .ESEG !\n");
 						// error_count++;
