@@ -144,7 +144,7 @@ int parse_directive(struct prog_info *pi)
 			if(!get_expr(pi, next, &i))
 				return(False);
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "D:%06x    %s", pi->dseg_addr, pi->list_line);
+				fprintf(pi->list_file, "D:%06x    %s\n", pi->dseg_addr, pi->list_line);
 				pi->list_line = NULL;
 			}
 			pi->dseg_addr += i;
@@ -160,7 +160,7 @@ int parse_directive(struct prog_info *pi)
 			break;
 		case DIRECTIVE_DB:
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "          %s", pi->list_line);
+				fprintf(pi->list_file, "          %s\n", pi->list_line);
 				pi->list_line = NULL;
 			}
 			return(parse_db(pi, next));
@@ -294,7 +294,7 @@ int parse_directive(struct prog_info *pi)
 						write_prog_word(pi, pi->cseg_addr, i);
 						// Actual fiddling 
 						if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-							fprintf(pi->list_file, "          %s", pi->list_line);
+							fprintf(pi->list_file, "          %s\n", pi->list_line);
 							pi->list_line = NULL;
 							fprintf(pi->list_file, "C:%06x %04x\n", pi->cseg_addr,i);
 						}
@@ -346,7 +346,7 @@ int parse_directive(struct prog_info *pi)
 				/* OK. Definition is unchanged */
 			}
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "          %s", pi->list_line);
+				fprintf(pi->list_file, "          %s\n", pi->list_line);
 				pi->list_line = NULL;
 			}
 			break;
@@ -369,7 +369,7 @@ int parse_directive(struct prog_info *pi)
 			}
 			next = term_string(pi, next);
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "          %s", pi->list_line);
+				fprintf(pi->list_file, "          %s\n", pi->list_line);
 				pi->list_line = NULL;
 			}
 			// Test if include is in local directory
@@ -475,7 +475,7 @@ int parse_directive(struct prog_info *pi)
 			if(pi->fi->label)
 				pi->fi->label->value = i;
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "          %s", pi->list_line);
+				fprintf(pi->list_file, "          %s\n", pi->list_line);
 				pi->list_line = NULL;
 			}
 			break;
@@ -535,7 +535,7 @@ int parse_directive(struct prog_info *pi)
 				/* OK. Definition is unchanged */
 			}
 			if((pi->pass == PASS_2) && pi->list_line && pi->list_on) {
-				fprintf(pi->list_file, "          %s", pi->list_line);
+				fprintf(pi->list_file, "          %s\n", pi->list_line);
 				pi->list_line = NULL;
 			}
 			break;
@@ -735,7 +735,9 @@ int parse_db(struct prog_info *pi, char *next) {
 		count++;
 		write_db(pi, *next, &prev, count);
         	if(pi->pass == PASS_2 && pi->list_on)
-          	fprintf(pi->list_file, "%02X", *next);
+          		fprintf(pi->list_file, "%02X", (unsigned char)*next);	// B.A.: Patch for chars with bit 7 = 1 (Example: °)
+		if((unsigned char)*next > 127 && pi->pass == PASS_2)
+			print_msg(pi, MSGTYPE_WARNING, "Found .DB string with characters > code 127. Be careful !"); // B.A.: Print warning for codes > 127
 		next++;
 	    }
 	}
@@ -816,7 +818,7 @@ int spool_conditional(struct prog_info *pi, int only_endif) {
 	  print_msg(pi, MSGTYPE_ERROR, "Found no closing .ENDIF in macro");
 	}
 	else {
-	  while(fgets(pi->fi->buff, LINEBUFFER_LENGTH, pi->fi->fp)) {
+	  while(fgets_new(pi,pi->fi->buff, LINEBUFFER_LENGTH, pi->fi->fp)) {
 	  pi->fi->line_number++;
 	    if(check_conditional(pi, pi->fi->buff, &current_depth,  &do_next, only_endif)) {
 		  if(!do_next)
@@ -847,7 +849,7 @@ int check_conditional(struct prog_info *pi, char *pbuff, int *current_depth, int
     strcpy(linebuff, pbuff); /* avoid cutting of the end of .elif line */
 
 	*do_next = False;
-	while(IS_HOR_SPACE(linebuff[i]) && !IS_END(linebuff[i])) i++;
+	while(IS_HOR_SPACE(linebuff[i]) && !IS_END_OR_COMMENT(linebuff[i])) i++;
 	if(linebuff[i] == '.') {
 	  i++;
 	  if(!nocase_strncmp(&linebuff[i], "if", 2))
