@@ -334,13 +334,12 @@ int get_expr(struct prog_info *pi, char *data, int *value) {
   end         = False;
   count       = 0;
   unary       = 0;
-
   /* the expression parser loop */
 	for(i = 0; ; i++) {
 	  /* horizontal space is just skipped */
 		if(IS_HOR_SPACE(data[i]));
 		/* test for clean or premature end */
-		else if(IS_END(data[i])) {
+		else if(IS_END_OR_COMMENT(data[i])) {
 			if((count % 2) != 1)
 				print_msg(pi, MSGTYPE_ERROR, "Missing value in expression");
 			else
@@ -354,7 +353,7 @@ int get_expr(struct prog_info *pi, char *data, int *value) {
 		else if((count % 2) == 1) {
 			if(!IS_OPERATOR(data[i])) {
 				print_msg(pi, MSGTYPE_ERROR, "Illegal operator '%c'", data[i]);
-        break;
+				break;
 			}
 			element = malloc(sizeof(struct element));
 			if(!element) {
@@ -414,10 +413,10 @@ int get_expr(struct prog_info *pi, char *data, int *value) {
 			}
 			else if(data[i] == '\'') {
 				i++;
-        if(data[i+1] != '\'') {
+				if(data[i+1] != '\'') {
 					print_msg(pi, MSGTYPE_ERROR, "Not a correct character ! Use 'A' !");
 					break;
-        }
+				}
 				element->data = data[i];
 				length = 2;
 			}
@@ -436,7 +435,7 @@ int get_expr(struct prog_info *pi, char *data, int *value) {
 			/* test for internal function */
 			else if((function = get_function(&data[i])) != -1) {
 				while(data[i] != '(')
-          i++;
+					i++;
 				i++;
 				length = par_length(&data[i]);
 				if(length == -1) {
